pub struct ProjectDatabase {
pub projects: Vec<Project>,
}Expand description
Persistent store of all registered projects, serialized as TOML.
Fields
projects: Vec<Project>Implementations
Sourceimpl ProjectDatabase
impl ProjectDatabase
Sourcepub fn load(config: &Config) -> Result<Self, PrjError>
pub fn load(config: &Config) -> Result<Self, PrjError>
Load the database from disk, or return an empty one if it doesn’t exist.
Sourcepub fn add(&mut self, project: Project) -> Result<(), PrjError>
pub fn add(&mut self, project: Project) -> Result<(), PrjError>
Add a project. Returns error if a project with the same path already exists.
Sourcepub fn remove(&mut self, name: &str) -> Result<Project, PrjError>
pub fn remove(&mut self, name: &str) -> Result<Project, PrjError>
Remove a project by name. Returns error if not found.
Sourcepub fn find_mut(&mut self, name: &str) -> Option<&mut Project>
pub fn find_mut(&mut self, name: &str) -> Option<&mut Project>
Find a project by name (mutable).
Add tags to a project.
Remove tags from a project.
Sourcepub fn find_orphaned(&self) -> Vec<&Project>
pub fn find_orphaned(&self) -> Vec<&Project>
Find projects whose paths no longer exist.
Sourcepub fn remove_orphaned(&mut self) -> Vec<Project>
pub fn remove_orphaned(&mut self) -> Vec<Project>
Remove projects whose paths no longer exist, returning the removed ones.